@@ -4,8 +4,7 @@ args=("$@")
 num_args=${#args[@]}
 index=0
 
-suite='shop'
-
+suite='shop addressmodel'
 coverage=false
 documentation=false
 ci=false
@@ -39,7 +38,7 @@ elif [ $coverage == true ]; then
 	cd tests/testapp
 	coverage run manage.py test $suite
 	coverage html
-	x-www-browser htmlcov/index.html
+	#x-www-browser htmlcov/index.html
 	popd
 
 else
