@@ -4,7 +4,7 @@ from shop.cart.cart_modifiers_base import BaseCartModifier
 
 class BulkRebateModifier(BaseCartModifier):
     
-    def add_extra_cart_item_price_field(self, cart_item):
+    def get_extra_cart_item_price_field(self, cart_item):
         """
         Add a rebate to a line item depending on the quantity ordered:
         
@@ -15,8 +15,8 @@ class BulkRebateModifier(BaseCartModifier):
         """
         REBATE_PERCENTAGE = Decimal('10')
         NUMBER_OF_ITEMS_TO_TRIGGER_REBATE = 5
+        result_tuple = None
         if cart_item.quantity >= NUMBER_OF_ITEMS_TO_TRIGGER_REBATE:
             rebate = (REBATE_PERCENTAGE/100) * cart_item.line_subtotal
-            to_append = ('Rebate', -rebate)
-            cart_item.extra_price_fields.append(to_append)
-        return cart_item
\ No newline at end of file
+            result_tuple = ('Rebate', -rebate)
+        return result_tuple # Returning None is ok
\ No newline at end of file
