@@ -20,6 +20,7 @@ class Cart(InclusionTag):
 
     def get_context(self, context):
         cart = get_or_create_cart(context['request'])
+        cart.update()
         return {
             'cart': cart
         }
@@ -52,7 +53,7 @@ class Products(InclusionTag):
     )
 
     def get_context(self, context, objects):
-        if not objects:
+        if objects is None:
             objects = Product.objects.filter(active=True)
         context.update({'products': objects, })
         return context
