@@ -18,8 +18,13 @@ class CurrencyField(DecimalField):
             del kwargs['default']
         return super(CurrencyField,self).__init__(max_digits=12,decimal_places=2,default=default,**kwargs)
 
-    def south_field_triple(self):
-        "Returns a suitable description of this field for South."
+    def south_field_triple(self): # pragma: no cover
+        """
+        Returns a suitable description of this field for South.
+        This is excluded from coverage reports since it is pretty much a piece
+        of South itself, and does not influence program behavior at all in
+        case we don't use South.
+        """
         # We'll just introspect the _actual_ field.
         from south.modelsinspector import introspector
         field_class = "django.db.models.fields.DecimalField"
